@@ -14,12 +14,23 @@ use vars qw(@ISA @SUBCMD_VARS);
 use vars @Devel::Trepan::CmdProcessor::Command::Subsubcmd::SUBCMD_VARS;
 
 our $IN_LIST      = 1;
+=pod
+
+=head2 Synopsis:
+
+=cut
+
 our $HELP         = <<'HELP';
 =pod
 
 B<set max list> I<count>
 
 Set number of source-code lines to list by default.
+
+=head2 See also:
+
+L<C<set max list>|Devel::Trepan::CmdProcessor::Set::Max::List>
+
 =cut
 HELP
 
